@@ -8,10 +8,10 @@ from datetime import datetime as dt
 
 
 
-class DbSqlA():
+class DbSqlA:
     base        = declarative_base()
     def __init__(self,ConnectionString):
-        self.engine                 = sa.create_engine(ConnectionString)
+        self.engine                 = sa.create_engine(ConnectionString,fast_executemany = True)
         self.session                = scoped_session(sessionmaker(autocommit=False,autoflush=False,bind=self.engine))
         self.base.query             = self.session.query_property()
         self.orm_session            = orm.scoped_session(orm.sessionmaker())(bind=self.engine)
@@ -22,22 +22,23 @@ class DbSqlA():
             create_database(self.engine.url)
         self.base.metadata.create_all(self.engine)
 
-    def save(self):
-        try:
-            if not self.id:
-                self.session.add(self)
-            self.session.commit()
-        except:
-            self.session.rollback()
-            raise
 
-    def delete(self):
-        self.session.rollback()
-        self.session.delete(self)
-        self.session.commit()
+def tblUts(db):
+    class auxDB:
+        id      = sa.Column(sa.Integer,primary_key=True,autoincrement=True)
 
+        def save(self):
+            try:
+                if not self.id:
+                    db.session.add(self)
+                db.session.commit()
+            except:
+                db.session.rollback()
+                raise
 
-class auxDB():
-    id      = sa.Column(sa.Integer,primary_key=True,autoincrement=True)
-
+        def delete(self):
+            db.session.rollback()
+            db.session.delete(self)
+            db.session.commit()
+    return auxDB
 
